====================
Data Portal Explorer
====================

.. image:: https://img.shields.io/badge/License-MIT-yellow.svg
        :target: https://opensource.org/licenses/MIT

.. image:: https://img.shields.io/pypi/v/data_portal_explorer.svg
        :target: https://pypi.python.org/pypi/data_portal_explorer

.. image:: https://github.com/kingsdigitallab/DataPortalExplorer/actions/workflows/main.yml/badge.svg
        :target: https://github.com/kingsdigitallab/DataPortalExplorer/actions/workflows/main.yml

.. image:: https://readthedocs.org/projects/dataportalexplorer/badge/?version=latest
        :target: https://dataportalexplorer.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


This package contains tools to extract metadata from CKAN instances which can
be used to study data portals as infrastructures from the perspective of
social/cultural research.


* Documentation: https://dataportalexplorer.readthedocs.io.


Credits
-------

This package was created with Cookiecutter_ and the
`audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
